==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/shells/generic/iggframeobjectcontrols.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A frame containing the full set of an object (iActorProp) controls
//

#ifndef IGGFRAMEOBJECTCONTROLS_H
#define IGGFRAMEOBJECTCONTROLS_H


#include "iggframe.h"


class iObjectKey;
class iString;

class iggFramePosition;
class iggFramePushControls;


class iggFrameObjectControls : public iggFrame
{

public:

	iggFrameObjectControls(const iString &name, const iObjectKey &poskey, const iObjectKey &dirkey, const iObjectKey &sizkey, const iObjectKey &markey, const iObjectKey &pickey, iggFrame *parent);

	void EnablePosition(bool s);
	void EnableDirection(bool s);
	void EnableSize(bool s);

protected:

	iggFramePosition *mOP;
	iggFrame *mOD, *mOS;
	iggFramePushControls *mPO;
};

#endif  // IGGFRAMEOBJECTCONTROLS_H

==> ifrit_3.2.5.orig.tar.gz: ifrit-3.2.5/shells/generic/iggframeobjectcontrols.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A frame containing the full set of an object (iActorProp) controls
//

#ifndef IGGFRAMEOBJECTCONTROLS_H
#define IGGFRAMEOBJECTCONTROLS_H


#include "iggframe.h"


class iObjectKey;
class iString;

class iggFramePosition;
class iggFramePushControls;


class iggFrameObjectControls : public iggFrame
{

public:

	iggFrameObjectControls(const iString &name, const iObjectKey &poskey, const iObjectKey &dirkey, const iObjectKey &sizkey, iggFrame *parent);

	void EnablePosition(bool s);
	void EnableDirection(bool s);
	void EnableSize(bool s);

protected:

	iggFramePosition *mOP;
	iggFrame *mOD, *mOS;
	iggFramePushControls *mPO;
};

#endif  // IGGFRAMEOBJECTCONTROLS_H
